
//=================================================================================================================================
// NAME: WiFiClient  based on NODEMCU8266 Local Client basic
// Author Ugo Schiara
// Date 11/02/2023
// Purpose: to configure the NodeMCU8266 Mini D1 from AZ-Delivery as a local WiFi Client in Station mode (STA) to connect another 
//          NODEMCU configured as a Server that links others NODEMCU's and a PAD (phone) to control the home automation. No need
//          to connect a router, therefore no remote control (no internet connection).
// Version 1.0  Once established the communication with the server, every 5 seconds it sends a request to switch ON /OFF a relay
//=================================================================================================================================
#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>


#define STASSID "esp_ap"                      // SSID of the local WiFi network created by the Server AP.  No passwords

const char* ssid = STASSID;
unsigned long timeout;


//====================================================================================
String httpGETRequest(const char* serverName) 
{
  WiFiClient client;
  HTTPClient http;    

  http.begin(client, serverName);             // This client IP address and the request  
    
  int httpResponseCode = http.GET();          // Send HTTP POST request
   String payload = "--";                     // initializes empty response   
  
  if (httpResponseCode>0) 
  {
    Serial.print("HTTP Response code: ");     // for debug purposes
    Serial.println(httpResponseCode);         // The code is >= 200 the answer is good
    payload = http.getString();               // get the response
  }
  else {
    Serial.print("Error code: ");             // The code is < 0 the answer is fail
    Serial.println(httpResponseCode);
  }
  http.end();                                 // Free resources
  return payload;                             // returns the received string to the caller
}



//==========================================================================================================
void setup() {
  Serial.begin(115200);

  Serial.print("Connecting to ");             // for debug purposes
  Serial.println(ssid);
 
  WiFi.mode(WIFI_STA);                        // sets the mode of operation on WiFi
  WiFi.begin(ssid);                           // try to connect the Server

  while (WiFi.status() != WL_CONNECTED)       // waits until connected
  {
    delay(500);                               // waits
    Serial.print(".");                        // still alive on serial monitor
    ESP.wdtFeed();                            // keep calm the WD (the NODEMCU has a hardware WatchDog that fires every 3 seconds)
  }

  Serial.println("");                         // for debug purposes
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());             // needed to be used in "Get" calls
  timeout = millis();                         // from this point onward no more delay() will be used becuse it could block 
                                              //    the other activities but millis() is used
}


//=====================================================================================================================================
void loop() 
{
      while (millis() - timeout < 5000)  ESP.wdtFeed();                   // waits for 5 seconds, in the meanwhile it keeps calm the WD
      Serial.println("sending data to server");                           // for debug purposes
      Serial.println(httpGETRequest("http://192.168.4.2/RELE/2/on"));     // Relay ON request. Its answer is printed on serial monitor
      timeout = millis();                                                 // time = now
      while (millis() - timeout < 5000)  ESP.wdtFeed();                   // waits for 5 seconds, in the meanwhile it keeps calm the WD
      timeout = millis();                                                 // time = now
      Serial.println("sending data to server");                           // for debug purposes
      Serial.println(httpGETRequest("http://192.168.4.2/RELE/2/off"));    // Relay ON request.Its answer is printed on serial monitor 
}
